@@ -9,11 +9,11 @@ var ErrorDump = `
 
 // http://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBInstances.html
 var DescribeDBInstancesExample = `
-<DescribeDBInstancesResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<DescribeDBInstancesResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <DescribeDBInstancesResult>
     <DBInstances>
       <DBInstance>
-        <BackupRetentionPeriod>1</BackupRetentionPeriod>
+        <BackupRetentionPeriod>7</BackupRetentionPeriod>
         <MultiAZ>false</MultiAZ>
         <DBInstanceStatus>available</DBInstanceStatus>
         <VpcSecurityGroups/>
@@ -54,14 +54,20 @@ var DescribeDBInstancesExample = `
         <AutoMinorVersionUpgrade>true</AutoMinorVersionUpgrade>
         <InstanceCreateTime>2014-01-29T22:58:24.231Z</InstanceCreateTime>
         <AllocatedStorage>5</AllocatedStorage>
+        <StorageType>gp2</StorageType>
         <MasterUsername>myawsuser</MasterUsername>
         <DBInstanceClass>db.t1.micro</DBInstanceClass>
       </DBInstance>
       <DBInstance>
-        <BackupRetentionPeriod>1</BackupRetentionPeriod>
+        <BackupRetentionPeriod>7</BackupRetentionPeriod>
         <MultiAZ>false</MultiAZ>
         <DBInstanceStatus>available</DBInstanceStatus>
-        <VpcSecurityGroups/>
+        <VpcSecurityGroups>
+          <VpcSecurityGroupMembership>
+            <Status>active</Status>
+            <VpcSecurityGroupId>my-vpc-secgroup</VpcSecurityGroupId>
+          </VpcSecurityGroupMembership>
+        </VpcSecurityGroups>
         <DBInstanceIdentifier>mysqlexampledb-restore</DBInstanceIdentifier>
         <PreferredBackupWindow>10:07-10:37</PreferredBackupWindow>
         <PreferredMaintenanceWindow>sun:06:13-sun:06:43</PreferredMaintenanceWindow>
@@ -88,12 +94,7 @@ var DescribeDBInstancesExample = `
             <Status>in-sync</Status>
           </OptionGroupMembership>
         </OptionGroupMemberships>
-        <DBSecurityGroups>
-          <DBSecurityGroup>
-            <Status>active</Status>
-            <DBSecurityGroupName>default</DBSecurityGroupName>
-          </DBSecurityGroup>
-        </DBSecurityGroups>
+        <DBSecurityGroups/>
         <PubliclyAccessible>true</PubliclyAccessible>
         <DBName>mysampledb</DBName>
         <AutoMinorVersionUpgrade>true</AutoMinorVersionUpgrade>
@@ -111,10 +112,10 @@ var DescribeDBInstancesExample = `
 `
 
 var CreateDBInstanceExample = `
-<CreateDBInstanceResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<CreateDBInstanceResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <CreateDBInstanceResult>
     <DBInstance>
-      <BackupRetentionPeriod>1</BackupRetentionPeriod>
+      <BackupRetentionPeriod>7</BackupRetentionPeriod>
       <DBInstanceStatus>creating</DBInstanceStatus>
       <MultiAZ>false</MultiAZ>
       <VpcSecurityGroups/>
@@ -161,10 +162,10 @@ var CreateDBInstanceExample = `
 `
 
 var DeleteDBInstanceExample = `
-<DeleteDBInstanceResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<DeleteDBInstanceResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <DeleteDBInstanceResult>
     <DBInstance>
-      <BackupRetentionPeriod>2</BackupRetentionPeriod>
+      <BackupRetentionPeriod>7</BackupRetentionPeriod>
       <DBInstanceStatus>deleting</DBInstanceStatus>
       <MultiAZ>false</MultiAZ>
       <VpcSecurityGroups/>
@@ -212,10 +213,11 @@ var DeleteDBInstanceExample = `
   <ResponseMetadata>
     <RequestId>7369556f-b70d-11c3-faca-6ba18376ea1b</RequestId>
   </ResponseMetadata>
-</DeleteDBInstanceResponse>`
+</DeleteDBInstanceResponse>
+`
 
 var DescribeDBSecurityGroupsExample = `
-<DescribeDBSecurityGroupsResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<DescribeDBSecurityGroupsResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <DescribeDBSecurityGroupsResult>
     <DBSecurityGroups>
       <DBSecurityGroup>
@@ -261,17 +263,19 @@ var DescribeDBSecurityGroupsExample = `
   <ResponseMetadata>
     <RequestId>b76e692c-b98c-11d3-a907-5a2c468b9cb0</RequestId>
   </ResponseMetadata>
-</DescribeDBSecurityGroupsResponse>`
+</DescribeDBSecurityGroupsResponse>
+`
 
 var DeleteDBSecurityGroupExample = `
-<DeleteDBSecurityGroupResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<DeleteDBSecurityGroupResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <ResponseMetadata>
     <RequestId>7aec7454-ba25-11d3-855b-576787000e19</RequestId>
   </ResponseMetadata>
 </DeleteDBSecurityGroupResponse>
 `
+
 var CreateDBSecurityGroupExample = `
-<CreateDBSecurityGroupResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<CreateDBSecurityGroupResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <CreateDBSecurityGroupResult>
     <DBSecurityGroup>
       <EC2SecurityGroups/>
@@ -288,7 +292,7 @@ var CreateDBSecurityGroupExample = `
 `
 
 var AuthorizeDBSecurityGroupIngressExample = `
-<AuthorizeDBSecurityGroupIngressResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<AuthorizeDBSecurityGroupIngressResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <AuthorizeDBSecurityGroupIngressResult>
     <DBSecurityGroup>
       <EC2SecurityGroups>
@@ -329,7 +333,7 @@ var AuthorizeDBSecurityGroupIngressExample = `
 `
 
 var DescribeDBSubnetGroupsExample = `
-<DescribeDBSubnetGroupsResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<DescribeDBSubnetGroupsResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <DescribeDBSubnetGroupsResult>
     <DBSubnetGroups>
       <DBSubnetGroup>
@@ -397,7 +401,7 @@ var DescribeDBSubnetGroupsExample = `
 `
 
 var DeleteDBSubnetGroupExample = `
-<DeleteDBSubnetGroupResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<DeleteDBSubnetGroupResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <ResponseMetadata>
     <RequestId>6295e5ab-bbf3-11d3-f4c6-37db295f7674</RequestId>
   </ResponseMetadata>
@@ -405,7 +409,7 @@ var DeleteDBSubnetGroupExample = `
 `
 
 var CreateDBSubnetGroupExample = `
-<CreateDBSubnetGroupResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<CreateDBSubnetGroupResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <CreateDBSubnetGroupResult>
     <DBSubnetGroup>
       <VpcId>vpc-33dc97ea</VpcId>
@@ -439,7 +443,7 @@ var CreateDBSubnetGroupExample = `
 `
 
 var DescribeDBSnapshotsExample = `
-<DescribeDBSnapshotsResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<DescribeDBSnapshotsResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <DescribeDBSnapshotsResult>
     <DBSnapshots>
       <DBSnapshot>
@@ -502,10 +506,10 @@ var DescribeDBSnapshotsExample = `
 `
 
 var RestoreDBInstanceFromDBSnapshotExample = `
-<RestoreDBInstanceFromDBSnapshotResponse xmlns="http://rds.amazonaws.com/doc/2013-09-09/">
+<RestoreDBInstanceFromDBSnapshotResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <RestoreDBInstanceFromDBSnapshotResult>
     <DBInstance>
-      <BackupRetentionPeriod>2</BackupRetentionPeriod>
+      <BackupRetentionPeriod>7</BackupRetentionPeriod>
       <MultiAZ>false</MultiAZ>
       <DBInstanceStatus>creating</DBInstanceStatus>
       <VpcSecurityGroups/>
@@ -548,3 +552,88 @@ var RestoreDBInstanceFromDBSnapshotExample = `
   </ResponseMetadata>
 </RestoreDBInstanceFromDBSnapshotResponse>
 `
+
+var CreateDBParameterGroupExample = `
+<CreateDBParameterGroupResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
+  <CreateDBParameterGroupResult>
+    <DBParameterGroup>
+      <DBParameterGroupFamily>mysql5.1</DBParameterGroupFamily>
+      <Description>My new DB Parameter Group</Description>
+      <DBParameterGroupName>mydbparamgroup3</DBParameterGroupName>
+    </DBParameterGroup>
+  </CreateDBParameterGroupResult>
+  <ResponseMetadata>
+    <RequestId>7805c127-af22-11c3-96ac-6999cc5f7e72</RequestId>
+  </ResponseMetadata>
+</CreateDBParameterGroupResponse>
+`
+
+var DescribeDBParameterGroupsExample = `
+<DescribeDBParameterGroupsResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
+  <DescribeDBParameterGroupsResult>
+    <DBParameterGroups>
+      <DBParameterGroup>
+        <DBParameterGroupFamily>mysql5.6</DBParameterGroupFamily>
+        <Description>My new DB Parameter Group</Description>
+        <DBParameterGroupName>mydbparamgroup3</DBParameterGroupName>
+      </DBParameterGroup>
+    </DBParameterGroups>
+  </DescribeDBParameterGroupsResult>
+  <ResponseMetadata>
+    <RequestId>b75d527a-b98c-11d3-f272-7cd6cce12cc5</RequestId>
+  </ResponseMetadata>
+</DescribeDBParameterGroupsResponse>
+`
+
+
+var DeleteDBParameterGroupExample = `
+<DeleteDBParameterGroupResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
+  <ResponseMetadata>
+    <RequestId>cad6c267-ba25-11d3-fe11-33d33a9bb7e3</RequestId>
+  </ResponseMetadata>
+</DeleteDBParameterGroupResponse>
+`
+
+var ModifyDBParameterGroupExample = `
+<ModifyDBParameterGroupResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
+  <ModifyDBParameterGroupResult>
+    <DBParameterGroupName>mydbparamgroup3</DBParameterGroupName>
+  </ModifyDBParameterGroupResult>
+  <ResponseMetadata>
+    <RequestId>12d7435e-bba0-11d3-fe11-33d33a9bb7e3</RequestId>
+  </ResponseMetadata>
+</ModifyDBParameterGroupResponse>
+`
+
+var DescribeDBParametersExample = `
+<DescribeDBParametersResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
+  <DescribeDBParametersResult>
+    <Marker>bGlzdGVuZXJfbmV0d29ya3M=</Marker>
+    <Parameters>
+      <Parameter>
+        <ParameterValue>utf8</ParameterValue>
+        <ParameterName>character_set_server</ParameterName>
+      </Parameter>
+      <Parameter>
+        <ParameterValue>utf8</ParameterValue>
+        <ParameterName>character_set_client</ParameterName>
+      </Parameter>
+      <Parameter>
+        <ParameterValue>utf8</ParameterValue>
+        <ParameterName>character_set_results</ParameterName>
+      </Parameter>
+      <Parameter>
+        <ParameterValue>utf8_unicode_ci</ParameterValue>
+        <ParameterName>collation_server</ParameterName>
+      </Parameter>
+      <Parameter>
+        <ParameterValue>utf8_unicode_ci</ParameterValue>
+        <ParameterName>collation_connection</ParameterName>
+      </Parameter>
+    </Parameters>
+  </DescribeDBParametersResult>
+  <ResponseMetadata>
+    <RequestId>8c40488f-b9ff-11d3-a15e-7ac49293f4fa</RequestId>
+  </ResponseMetadata>
+</DescribeDBParametersResponse>
+`
