@@ -5,8 +5,9 @@ import (
 	"crypto/sha256"
 	"encoding/base64"
 	"fmt"
-	"github.com/mitchellh/goamz/aws"
 	"time"
+
+	"github.com/mitchellh/goamz/aws"
 )
 
 var b64 = base64.StdEncoding
@@ -22,4 +23,7 @@ func sign(auth aws.Auth, path string, params map[string]string) {
 	header := fmt.Sprintf("AWS3-HTTPS AWSAccessKeyId=%s,Algorithm=HmacSHA256,Signature=%s",
 		auth.AccessKey, signature)
 	params["X-Amzn-Authorization"] = string(header)
+	if auth.Token != "" {
+		params["X-Amz-Security-Token"] = auth.Token
+	}
 }
