@@ -1,6 +1,7 @@
 import os
 import hashlib
 import inspect
+import zlib
 from lib import BaseTest
 
 
@@ -12,6 +13,13 @@ def sorted_processor(output):
     return "\n".join(sorted(output.split("\n")))
 
 
+def ungzip_if_required(output):
+    if output.startswith("\x1f\x8b"):
+        return zlib.decompress(output, 16+zlib.MAX_WBITS)
+
+    return output
+
+
 class PublishSnapshot1Test(BaseTest):
     """
     publish snapshot: defaults
@@ -35,10 +43,12 @@ class PublishSnapshot1Test(BaseTest):
         self.check_exists('public/dists/maverick/main/binary-i386/Packages')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-i386.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Release')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-amd64.gz')
         self.check_not_exists('public/dists/maverick/main/debian-installer/binary-i386/Packages')
         self.check_not_exists('public/dists/maverick/main/debian-installer/binary-amd64/Packages')
 
@@ -53,6 +63,9 @@ class PublishSnapshot1Test(BaseTest):
         self.check_file_contents('public/dists/maverick/main/binary-i386/Packages', 'packages_i386', match_prepare=sorted_processor)
         self.check_file_contents('public/dists/maverick/main/binary-amd64/Packages', 'packages_amd64', match_prepare=sorted_processor)
 
+        self.check_file_contents('public/dists/maverick/main/Contents-i386.gz', 'contents_i386', match_prepare=ungzip_if_required)
+        self.check_file_contents('public/dists/maverick/main/Contents-amd64.gz', 'contents_amd64', match_prepare=ungzip_if_required)
+
         # verify signatures
         self.run_cmd(["gpg", "--no-auto-check-trustdb", "--keyring", os.path.join(os.path.dirname(inspect.getsourcefile(BaseTest)), "files", "aptly.pub"),
                       "--verify", os.path.join(os.environ["HOME"], ".aptly", 'public/dists/maverick/InRelease')])
@@ -88,7 +101,8 @@ class PublishSnapshot1Test(BaseTest):
 
         if pathsSeen != set(['main/binary-amd64/Packages', 'main/binary-i386/Packages', 'main/binary-i386/Packages.gz',
                              'main/binary-amd64/Packages.gz', 'main/binary-amd64/Packages.bz2', 'main/binary-i386/Packages.bz2',
-                             'main/binary-amd64/Release', 'main/binary-i386/Release']):
+                             'main/binary-amd64/Release', 'main/binary-i386/Release', 'main/Contents-amd64.gz',
+                             'main/Contents-i386.gz']):
             raise Exception("path seen wrong: %r" % (pathsSeen, ))
 
 
@@ -114,9 +128,11 @@ class PublishSnapshot2Test(BaseTest):
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages')
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/squeeze/main/Contents-i386.gz')
         self.check_exists('public/dists/squeeze/main/binary-amd64/Packages')
         self.check_exists('public/dists/squeeze/main/binary-amd64/Packages.gz')
         self.check_exists('public/dists/squeeze/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/squeeze/main/Contents-amd64.gz')
 
         self.check_exists('public/pool/main/g/gnuplot/gnuplot-doc_4.6.1-1~maverick2_all.deb')
 
@@ -146,9 +162,11 @@ class PublishSnapshot3Test(BaseTest):
         self.check_exists('public/dists/squeeze/contrib/binary-i386/Packages')
         self.check_exists('public/dists/squeeze/contrib/binary-i386/Packages.gz')
         self.check_exists('public/dists/squeeze/contrib/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/squeeze/contrib/Contents-i386.gz')
         self.check_exists('public/dists/squeeze/contrib/binary-amd64/Packages')
         self.check_exists('public/dists/squeeze/contrib/binary-amd64/Packages.gz')
         self.check_exists('public/dists/squeeze/contrib/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/squeeze/contrib/Contents-amd64.gz')
 
         self.check_exists('public/pool/contrib/g/gnuplot/gnuplot-doc_4.6.1-1~maverick2_all.deb')
 
@@ -178,9 +196,11 @@ class PublishSnapshot4Test(BaseTest):
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages')
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/squeeze/main/Contents-i386.gz')
         self.check_not_exists('public/dists/squeeze/main/binary-amd64/Packages')
         self.check_not_exists('public/dists/squeeze/main/binary-amd64/Packages.gz')
         self.check_not_exists('public/dists/squeeze/main/binary-amd64/Packages.bz2')
+        self.check_not_exists('public/dists/squeeze/main/Contents-amd64.gz')
 
         self.check_exists('public/pool/main/g/gnuplot/gnuplot-doc_4.6.1-1~maverick2_all.deb')
 
@@ -211,9 +231,11 @@ class PublishSnapshot5Test(BaseTest):
         self.check_exists('public/ppa/smira/dists/squeeze/main/binary-i386/Packages')
         self.check_exists('public/ppa/smira/dists/squeeze/main/binary-i386/Packages.gz')
         self.check_exists('public/ppa/smira/dists/squeeze/main/binary-i386/Packages.bz2')
+        self.check_exists('public/ppa/smira/dists/squeeze/main/Contents-i386.gz')
         self.check_exists('public/ppa/smira/dists/squeeze/main/binary-amd64/Packages')
         self.check_exists('public/ppa/smira/dists/squeeze/main/binary-amd64/Packages.gz')
         self.check_exists('public/ppa/smira/dists/squeeze/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/ppa/smira/dists/squeeze/main/Contents-amd64.gz')
 
         self.check_exists('public/ppa/smira/pool/main/g/gnuplot/gnuplot-doc_4.6.1-1~maverick2_all.deb')
 
@@ -327,9 +349,11 @@ class PublishSnapshot13Test(BaseTest):
         self.check_exists('public/dists/maverick/main/binary-i386/Packages')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-i386.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-amd64.gz')
 
         # verify contents except of sums
         self.check_file_contents('public/dists/maverick/Release', 'release', match_prepare=strip_processor)
@@ -370,9 +394,11 @@ class PublishSnapshot15Test(BaseTest):
         self.check_exists('public/dists/maverick/main/binary-i386/Packages')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-i386.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-amd64.gz')
 
         # verify contents except of sums
         self.check_file_contents('public/dists/maverick/Release', 'release', match_prepare=strip_processor)
@@ -400,12 +426,15 @@ class PublishSnapshot16Test(BaseTest):
         self.check_exists('public/dists/maverick/main/binary-i386/Packages')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-i386.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-amd64.gz')
         self.check_exists('public/dists/maverick/main/source/Sources')
         self.check_exists('public/dists/maverick/main/source/Sources.gz')
         self.check_exists('public/dists/maverick/main/source/Sources.bz2')
+        self.check_not_exists('public/dists/maverick/main/Contents-source.gz')
 
         self.check_exists('public/pool/main/g/gnuplot/gnuplot-doc_4.6.1-1~maverick2_all.deb')
         self.check_exists('public/pool/main/g/gnuplot/gnuplot_4.6.1-1~maverick2.debian.tar.gz')
@@ -446,9 +475,11 @@ class PublishSnapshot17Test(BaseTest):
         self.check_exists('public/dists/maverick/main/binary-i386/Packages')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-i386.gz')
         self.check_exists('public/dists/maverick/main/source/Sources')
         self.check_exists('public/dists/maverick/main/source/Sources.gz')
         self.check_exists('public/dists/maverick/main/source/Sources.bz2')
+        self.check_not_exists('public/dists/maverick/main/Contents-source.gz')
 
         self.check_exists('public/pool/main/p/pyspi/pyspi_0.6.1-1.3.dsc')
         self.check_exists('public/pool/main/p/pyspi/pyspi_0.6.1-1.3.diff.gz')
@@ -643,19 +674,24 @@ class PublishSnapshot26Test(BaseTest):
         self.check_exists('public/dists/maverick/main/binary-i386/Packages')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-i386.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.gz')
         self.check_exists('public/dists/maverick/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/maverick/main/Contents-amd64.gz')
         self.check_exists('public/dists/maverick/main/source/Sources')
         self.check_exists('public/dists/maverick/main/source/Sources.gz')
         self.check_exists('public/dists/maverick/main/source/Sources.bz2')
+        self.check_not_exists('public/dists/maverick/main/Contents-source.gz')
 
         self.check_exists('public/dists/maverick/contrib/binary-i386/Packages')
         self.check_exists('public/dists/maverick/contrib/binary-i386/Packages.gz')
         self.check_exists('public/dists/maverick/contrib/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/maverick/contrib/Contents-i386.gz')
         self.check_exists('public/dists/maverick/contrib/binary-amd64/Packages')
         self.check_exists('public/dists/maverick/contrib/binary-amd64/Packages.gz')
         self.check_exists('public/dists/maverick/contrib/binary-amd64/Packages.bz2')
+        self.check_not_exists('public/dists/maverick/contrib/Contents-amd64.gz')
         self.check_exists('public/dists/maverick/contrib/source/Sources')
         self.check_exists('public/dists/maverick/contrib/source/Sources.gz')
         self.check_exists('public/dists/maverick/contrib/source/Sources.bz2')
@@ -710,7 +746,8 @@ class PublishSnapshot26Test(BaseTest):
                              'contrib/binary-amd64/Packages.gz', 'contrib/binary-amd64/Packages.bz2', 'contrib/binary-i386/Packages.bz2',
                              'contrib/source/Sources', 'contrib/source/Sources.gz', 'contrib/source/Sources.bz2',
                              'main/binary-amd64/Release', 'main/binary-i386/Release', 'main/source/Release',
-                             'contrib/binary-amd64/Release', 'contrib/binary-i386/Release', 'contrib/source/Release']):
+                             'contrib/binary-amd64/Release', 'contrib/binary-i386/Release', 'contrib/source/Release',
+                             'contrib/Contents-i386.gz', 'main/Contents-i386.gz', 'main/Contents-amd64.gz']):
             raise Exception("path seen wrong: %r" % (pathsSeen, ))
 
 
@@ -859,18 +896,22 @@ class PublishSnapshot35Test(BaseTest):
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages')
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages.gz')
         self.check_exists('public/dists/squeeze/main/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/squeeze/main/Contents-i386.gz')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-i386/Release')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-i386/Packages')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-i386/Packages.gz')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-i386/Packages.bz2')
+        self.check_exists('public/dists/squeeze/main/Contents-udeb-i386.gz')
         self.check_exists('public/dists/squeeze/main/binary-amd64/Release')
         self.check_exists('public/dists/squeeze/main/binary-amd64/Packages')
         self.check_exists('public/dists/squeeze/main/binary-amd64/Packages.gz')
         self.check_exists('public/dists/squeeze/main/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/squeeze/main/Contents-amd64.gz')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-amd64/Release')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-amd64/Packages')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-amd64/Packages.gz')
         self.check_exists('public/dists/squeeze/main/debian-installer/binary-amd64/Packages.bz2')
+        self.check_exists('public/dists/squeeze/main/Contents-udeb-amd64.gz')
         self.check_not_exists('public/dists/squeeze/main/source/Sources')
         self.check_not_exists('public/dists/squeeze/main/source/Sources.gz')
         self.check_not_exists('public/dists/squeeze/main/source/Sources.bz2')
@@ -922,7 +963,33 @@ class PublishSnapshot35Test(BaseTest):
                 for ext in ("", ".gz", ".bz2"):
                     pathsExepcted.add("main/%sbinary-%s/Packages%s" % (udeb, arch, ext))
 
+                pathsExepcted.add("main/Contents-%s%s.gz" % ("udeb-" if udeb != "" else "", arch))
+
                 pathsExepcted.add("main/%sbinary-%s/Release" % (udeb, arch))
 
         if pathsSeen != pathsExepcted:
             raise Exception("path seen wrong: %r != %r" % (pathsSeen, pathsExepcted))
+
+
+class PublishSnapshot36Test(BaseTest):
+    """
+    publish snapshot: -skip-contents
+    """
+    fixtureDB = True
+    fixturePool = True
+    fixtureCmds = [
+        "aptly snapshot create snap36 from mirror gnuplot-maverick",
+    ]
+    runCmd = "aptly publish snapshot -keyring=${files}/aptly.pub -secret-keyring=${files}/aptly.sec -skip-contents snap36"
+    gold_processor = BaseTest.expand_environ
+
+    def check(self):
+        super(PublishSnapshot36Test, self).check()
+
+        self.check_exists('public/dists/maverick/Release')
+        self.check_exists('public/dists/maverick/Release.gpg')
+
+        self.check_exists('public/dists/maverick/main/binary-i386/Release')
+        self.check_not_exists('public/dists/maverick/main/Contents-i386.gz')
+        self.check_exists('public/dists/maverick/main/binary-amd64/Release')
+        self.check_not_exists('public/dists/maverick/main/Contents-amd64.gz')
